@@ -151,7 +151,7 @@ def create_split_tfrecords_from_csv(data_dir, csv_path, outfile1name, outfile2na
 
 
 
-def create_split_tfrecords_data(data_dir, outfile1name, outfile2name, split_size_ratio, IMAGE_SIZE = (192,192)):
+def create_split_tfrecords_data(data_dir, outfile1name, output1folder, outfile2name, output2folder, split_size_ratio,num_parts1 = 1, num_parts2 = 1,  IMAGE_SIZE = (192,192)):
 
 	print(f"Split ratio -> {split_size_ratio}")
 	addrs, labels = get_addrs_labels(data_dir)
@@ -161,13 +161,19 @@ def create_split_tfrecords_data(data_dir, outfile1name, outfile2name, split_size
 
 	file2_addrs = addrs[int(split_size_ratio * len(addrs)) :]
 	file2_labels =  labels[int(split_size_ratio * len(labels)):]
-
-	create_tfrecord_labeled(file1_addrs, file1_labels, outfile1name, IMAGE_SIZE)
-	create_tfrecord_labeled(file2_addrs, file2_labels, outfile2name, IMAGE_SIZE)
-
+	
+	os.mkdir(output1folder); os.mkdir(output2folder)
+	
+	from pathlib import Path
+	os.chdir(output1folder)
+	create_tfrecord_labeled(file1_addrs, file1_labels, outfile1name, IMAGE_SIZE, num_parts1)
+	os.chdir(Path(os.getcwd()).parent)
+	os.chdir(output2folder)
+	create_tfrecord_labeled(file2_addrs, file2_labels, outfile2name, IMAGE_SIZE, num_parts2)
+	os.chdir(Path(os.getcwd()).parent)
+	
 	print("Data Successfully created!")
 
-
 def affirmationfolder(func):
 	def inner(*args,**kwargs):
 		print("""
@@ -190,74 +196,152 @@ def affirmationfolder(func):
 	return inner
 
 @affirmationfolder
-def create_tfrecord_labeled(addrs, labels, out_filename, IMAGE_SIZE = (192,192)):
+def create_tfrecord_labeled(addrs, labels, out_filename, IMAGE_SIZE = (192,192), num_parts = 1):
 
 
 
 	print(f"Beginning to write data to {out_filename}\n\n")
-	writer = tf.io.TFRecordWriter(out_filename)
-	for i in range(len(addrs)):
-		if i % 300 == 0:
-			print("Data written -> {}/{}".format(i, len(addrs)))
-			sys.stdout.flush()
-
-		# loading the image
-		img = load_image(addrs[i], IMAGE_SIZE)
-		label = labels[i]
-
-		if img is None:
-			continue
-
-		# feature creation
-
-		feature = {
-			'image' : _bytes_feature(img.tostring()),
-			'label' : _int64_feature(label)
-		}
-
+	if num_parts == 1:
 		
+		writer = tf.io.TFRecordWriter(out_filename)
+		for i in range(len(addrs)):
+			if i % 300 == 0:
+				print("Data written -> {}/{}".format(i, len(addrs)))
+				sys.stdout.flush()
 
-		# example protocol buffer
-		example = tf.train.Example(features = tf.train.Features(feature = feature))
+			# loading the image
+			img = load_image(addrs[i], IMAGE_SIZE)
+			label = labels[i]
 
-		# serialize the write the output to the file
-		writer.write(example.SerializeToString())
-	writer.close()
-	sys.stdout.flush()
-	print(f"Done with writing data to {out_filename}\n\n")
-	print("""
-			Your Labeled TFRecord Format is -> 
+			if img is None:
+				continue
 
-			{
-			'image' : tf.io.FixedLenFeature([], tf.string),
-			'label' : tf.io.FixedLenFeature([], tf.int64)
+			# feature creation
+
+			feature = {
+				'image' : _bytes_feature(img.tostring()),
+				'label' : _int64_feature(label)
 			}
 
-			You would be asked the TFRecord Format while reading the training and validation dataset.
-	""")
-	print("Now after you have obtained the tfrecords, you need to upload them to GCS Buckets to utlize TPU computation...")
-	print("To do so, the easiest method is uploading on Kaggle.")
-	print("""
-		1. Public Datasets
-
-		from kaggle_datasets import KaggleDatasets
-		GCS_DS_PATH = KaggleDatasets().get_gcs_path()
 
 
-		2. Private Datasets
+			# example protocol buffer
+			example = tf.train.Example(features = tf.train.Features(feature = feature))
 
-		# Get the credentials from the Cloud SDK
-		from kaggle_secrets import UserSecretsClient
-		user_secrets = UserSecretsClient()
-		user_credential = user_secrets.get_gcloud_credential()
+			# serialize the write the output to the file
+			writer.write(example.SerializeToString())
+		writer.close()
+		sys.stdout.flush()
+		print(f"Done with writing data to {out_filename}\n\n")
+		print("""
+				Your Labeled TFRecord Format is -> 
 
-		# Set the credentials
-		user_secrets.set_tensorflow_credential(user_credential)
+				{
+				'image' : tf.io.FixedLenFeature([], tf.string),
+				'label' : tf.io.FixedLenFeature([], tf.int64)
+				}
 
-		# Use a familiar call to get the GCS path of the dataset
-		from kaggle_datasets import KaggleDatasets
-		GCS_DS_PATH = KaggleDatasets().get_gcs_path()
+				You would be asked the TFRecord Format while reading the training and validation dataset.
 		""")
+		print("Now after you have obtained the tfrecords, you need to upload them to GCS Buckets to utlize TPU computation...")
+		print("To do so, the easiest method is uploading on Kaggle.")
+		print("""
+			1. Public Datasets
+
+			from kaggle_datasets import KaggleDatasets
+			GCS_DS_PATH = KaggleDatasets().get_gcs_path()
+
+
+			2. Private Datasets
+
+			# Get the credentials from the Cloud SDK
+			from kaggle_secrets import UserSecretsClient
+			user_secrets = UserSecretsClient()
+			user_credential = user_secrets.get_gcloud_credential()
+
+			# Set the credentials
+			user_secrets.set_tensorflow_credential(user_credential)
+
+			# Use a familiar call to get the GCS path of the dataset
+			from kaggle_datasets import KaggleDatasets
+			GCS_DS_PATH = KaggleDatasets().get_gcs_path()
+			""")
+	else:
+		
+		chunk_size = len(addrs) // num_parts
+		
+		indx = 0
+		
+		for part in range(num_parts):
+			writer = tf.io.TFRecordWriter(out_filename.split('.')[0] + f'_part_{part+1}.' + out_filename.split('.')[1])
+			addrs_ = addrs[indx : indx + chunk_size]
+			labels_ = labels[indx : indx + chunk_size]
+			if part == num_parts - 1:
+				addrs_ = addrs[indx:]
+				labels_ = labels[indx:]
+			for i in range(len(addrs_)):
+				if i % 100 == 0:
+					print("Data written -> {}/{}".format(i, len(addrs_)))
+					sys.stdout.flush()
+
+				# loading the image
+				img = load_image(addrs_[i], IMAGE_SIZE)
+				label = labels_[i]
+
+				if img is None:
+					continue
+
+				# feature creation
+
+				feature = {
+					'image' : _bytes_feature(img.tostring()),
+					'label' : _int64_feature(label)
+				}
+
+
+
+				# example protocol buffer
+				example = tf.train.Example(features = tf.train.Features(feature = feature))
+
+				# serialize the write the output to the file
+				writer.write(example.SerializeToString())
+			writer.close()
+			sys.stdout.flush()
+			indx = indx + chunk_size
+			print(f"Done with writing data to {out_filename.split('.')[0] + f'_part_{part+1}.' + out_filename.split('.')[1]}\n\n")
+			print("""
+				Your Labeled TFRecord Format is -> 
+
+				{
+				'image' : tf.io.FixedLenFeature([], tf.string),
+				'label' : tf.io.FixedLenFeature([], tf.int64)
+				}
+
+				You would be asked the TFRecord Format while reading the training and validation dataset.
+			""")
+			print("Now after you have obtained the tfrecords, you need to upload them to GCS Buckets to utlize TPU computation...")
+			print("To do so, the easiest method is uploading on Kaggle.")
+			print("""
+				1. Public Datasets
+
+				from kaggle_datasets import KaggleDatasets
+				GCS_DS_PATH = KaggleDatasets().get_gcs_path()
+
+
+				2. Private Datasets
+
+				# Get the credentials from the Cloud SDK
+				from kaggle_secrets import UserSecretsClient
+				user_secrets = UserSecretsClient()
+				user_credential = user_secrets.get_gcloud_credential()
+
+				# Set the credentials
+				user_secrets.set_tensorflow_credential(user_credential)
+	
+				# Use a familiar call to get the GCS path of the dataset
+				from kaggle_datasets import KaggleDatasets
+				GCS_DS_PATH = KaggleDatasets().get_gcs_path()
+				""")
 
 def get_addrs_ids(data_dir):
 	data_path = data_dir + '/*.jpg'
